@@ -1,9 +1,10 @@
 package Template::Liquid::Context;
-our $VERSION = '1.0.6';
+our $VERSION = '1.0.7';
 require Template::Liquid::Utility;
 require Template::Liquid::Error;
 use strict;
 use warnings;
+use Scalar::Util;
 
 sub new {
     my ($class, %args) = @_;
@@ -119,13 +120,20 @@ sub get {
     return !1  if $var eq 'false';
     return !!1 if $var eq 'true';
     return [$s->get($1) .. $s->get($2)]
-        if $var =~ m[^\((\S+)\.\.(\S+)\)$]o;    # range
+        if $var =~ m[^\((\S+)\s*\.\.\s*(\S+)\)$]o;    # range
     return $s->get($1)->[$2] if $var =~ m'^(.+)\[(\d+)\]$'o;
     return $s->get($1)->{$2} if $var =~ m'^(.+)\[(.+)\]$'o;
 STEP: while (@path) {
         my $crumb   = shift @path;
         my $reftype = ref $$cursor;
-        if ($reftype eq 'HASH') {
+        if (Scalar::Util::blessed($$cursor) && $$cursor->can($crumb)) {
+            my $can = $$cursor->can($crumb);
+            my $val = $can->($$cursor);
+            return $val if !scalar @path;
+            $cursor = \$val;
+            next STEP;
+        }
+        elsif ($reftype eq 'HASH') {
             if (exists $$cursor->{$crumb}) {
                 return $$cursor->{$crumb} if !@path;
                 $cursor = \$$cursor->{$crumb};
@@ -137,12 +145,13 @@ STEP: while (@path) {
             return scalar @{$$cursor} if $crumb eq 'size';
             $crumb = 0          if $crumb eq 'first';
             $crumb = $#$$cursor if $crumb eq 'last';
-            return () if $crumb =~ m[\D]o;
-            return () if scalar @$$cursor < $crumb;
+            return ()                 if $crumb =~ m[\D]o;
+            return ()                 if scalar @$$cursor < $crumb;
             return $$cursor->[$crumb] if !scalar @path;
             $cursor = \$$cursor->[$crumb];
             next STEP;
         }
+        die $var;
         return ();
     }
 }
