@@ -1,6 +1,7 @@
 package Template::Liquid::Variable;
-our $VERSION = '1.0.6';
+our $VERSION = '1.0.7';
 require Template::Liquid::Error;
+use strict;use warnings;
 use base 'Template::Liquid::Document';
 
 sub new {
@@ -33,6 +34,8 @@ sub render {
             my %_filters = $s->{template}->filters;
         FILTER: for my $filter (@{$s->{filters}}) {
                 my ($name, $args) = @$filter;
+                #warn join ', ', @$args;
+
                 map {
                     my $arg_val = $s->{template}{context}->get($_);
                     $_ = $arg_val if defined $arg_val;
@@ -40,13 +43,17 @@ sub render {
                 my $package = $_filters{$name};
                 my $call = $package ? $package->can($name) : ();
                 if ($call) {
+                    #use Data::Dump qw[dump];
+                    #warn sprintf 'Before %s(%s): %s', $name, dump($args), dump($val);
                     $val = $call->($val, @$args);
+                    #warn sprintf 'After  %s(%s): %s', $name, dump($args), dump($val);
                     next FILTER;
                 }
                 raise Template::Liquid::Error { type => 'UnknownFilter', message => $name, fatal => 0};
             }
         }
     }
+    #warn '---> ' . $s->{variable} . ' ===> ' .$val;
     return join '', @$val      if ref $val eq 'ARRAY';
     return join '', keys %$val if ref $val eq 'HASH';
     return $val;
